==> Weather-Com-0.4.1.tar.gz: Weather-Com-0.4.1/lib/Weather/Com/L10N/de.pm <==
package Weather::Com::L10N::de;

use base 'Weather::Com::L10N';

%Lexicon = (

	# some general things...
	'n/a'           => 'nicht verfgbar',
	'N/A'           => 'nicht verfgbar',
	'Not Available' => 'nicht verfgbar',
	'unknown'       => 'unbekannt',
	'NONE'          => 'keine',
	'day'           => 'Tag',
	'night'         => 'Nacht',

	# first all about moon phases
	'new'             => 'Neumond',
	'first quarter'   => 'Viertelmond',
	'full'            => 'Vollmond',
	'last quarter'    => 'Dreiviertelmond',
	'waning crescent' => 'abnehmend',
	'waning gibbous'  => 'abnehmend',
	'waxing crescent' => 'zunehmend',
	'waxing gibbous'  => 'zunehmend',

	# about UV Index...
	'extreme'   => 'extrem',
	'very high' => 'sehr hoch',
	'high'      => 'hoch',
	'moderate'  => 'moderat',
	'low'       => 'niedrig',

	# tendencies used for barometric pressure
	'rising'  => 'steigend',
	'falling' => 'fallend',
	'steady'  => 'stabil',

	# all about weather conditions
	'blowing dust'                 => 'Sandsturm',
	'blowing snow'                 => 'Schneesturm',
	'blowing snow and windy'       => 'Schneestreiben und windig',
	'clear'                        => 'klar',
	'cloudy'                       => 'bewlkt',
	'cloudy and windy'             => 'bewlkt und windig',
	'drizzle'                      => 'Nieselregen',
	'drifting snow'                => 'Schneetreiben',
	'fair'                         => 'heiter',
	'fair and windy'               => 'heiter und windig',
	'fog'                          => 'Nebel',
	'haze'                         => 'trb',
	'heavy drizzle'                => 'schwerer Sprhregen',
	'heavy rain'                   => 'schwerer Regen',
	'heavy rain and windy'         => 'schwerer Regen und windig',
	'heavy snow'                   => 'schwerer Schneefall',
	'heavy snow and windy'         => 'schwerer Schneefall und windig',
	'heavy t-storm'                => 'schweres Gewitter',
	'light drizzle'                => 'leichter Nieselregen',
	'light drizzle and windy'      => 'leichter Nieselregen und windig',
	'light freezing drizzle'       => 'leichter Eisregen',
	'light freezing rain'          => 'leichter Eisregen',
	'light rain'                   => 'leichter Regen',
	'light rain shower'            => 'leichte Regenschauer',
	'light rain and fog'           => 'leichter Regen und Nebel',
	'light rain and freezing rain' => 'leichter Regen und Eisregen',
	'light rain with thunder'      => 'leichter Regen und Donner',
	'light rain and windy'         => 'leichter Regen und windig',
	'light snow'                   => 'leichter Schneefall',
	'light snow shower'            => 'leichte Schneeschauer',
	'light snow and sleet'         => 'leichter Schneefall und Schneeregen',
	'light snow and windy'         => 'leichter Schneefall und windig',
	'mist'                         => 'Sprhregen',
	'mostly cloudy'                => 'berwiegend bewlkt',
	'mostly cloudy and windy'      => 'berwiegend bewlkt und windig',
	'partial fog'                  => 'rtlich Nebel',
	'partly cloudy'                => 'teilweise bewlkt',
	'partly cloudy and windy'      => 'teilweise bewlkt und windig',
	'patches of fog'               => 'Nebelfelder',
	'rain'                         => 'Regen',
	'rain and sleet'               => 'Regen und Schneeregen',
	'rain and snow'                => 'Schneeregen',
	'rain shower'                  => 'Regenschauern',
	'rain and fog'                 => 'Regen und Nebel',
	'rain and windy'               => 'Regen und windig',
	'sand'                         => 'Sand',
	'shallow fog'                  => 'Bodennebel',
	'showers in the vicinity'      => 'rtliche Schauern',
	'sleet'                        => 'Graupel',
	'smoke'                        => 'Dunst',
	'snow'                         => 'Schnee',
	'snow and fog'                 => 'Schneefall und nebelig',
	'snow and freezing rain'       => 'Schnee und Eisregen',
	'snow grains'                  => 'Schneegraupel',
	'snow showers'                 => 'Schneeschauern',
	'snow and windy and fog'       => 'Schneefall, windig und nebelig',
	'squalls and windy'            => 'Wind und Sturmben',
	'sunny'                        => 'sonnig',
	'sunny and windy'              => 'sonnig und windig',
	't-storm'                      => 'Unwetter',
	'thunder'                      => 'Gewitter',
	'thunder in the vicinity'      => 'rtliche Gewitter',
	'unknown precip'               => 'unbekannt',
	'widespread dust'              => 'verbreitet staubig',
	'wintry mix'                   => 'wechselnde Winde',

	# wind directions long
	'East'            => 'Osten',
	'East Northeast'  => 'Ost Nordost',
	'East Southeast'  => 'Ost Sdost',
	'North'           => 'Norden',
	'Northeast'       => 'Nordosten',
	'North Northeast' => 'Nord Nordost',
	'North Northwest' => 'Nord Nordwest',
	'Northwest'       => 'Nordwesten',
	'South'           => 'Sden',
	'Souteast'        => 'Sdosten',
	'South Southeast' => 'Sd Sdost',
	'South Southwest' => 'Sd Sdwest',
	'Southwest'       => 'Sdwesten',
	'variable'        => 'wechselnd',
	'West'            => 'Westen',
	'West Northwest'  => 'West Nordwest',
	'West Southwest'  => 'West Sdwest',

	# wind directions short
	'E'   => 'O',
	'ENE' => 'ONO',
	'ESE' => 'OSO',
	'N'   => 'N',
	'NE'  => 'NO',
	'NNE' => 'NNO',
	'NNW' => 'NNW',
	'NW'  => 'NW',
	'S'   => 'S',
	'SE'  => 'SO',
	'SSE' => 'SSO',
	'SSW' => 'SSW',
	'SW'  => 'SW',
	'VAR' => 'wechselnd',
	'W'   => 'W',
	'WNW' => 'WNW',
	'WSW' => 'WSW',
);

1;

==> Weather-Com-0.5.3.tar.gz: Weather-Com-0.5.3/lib/Weather/Com/L10N/de.pm <==
package Weather::Com::L10N::de;

use base 'Weather::Com::L10N';

# have a cvs driven version...
our $VERSION = sprintf "%d.%03d", q$Revision: 1.6 $ =~ /(\d+)/g;

%Lexicon = (

	# some general things...
	'n/a'           => 'nicht verfgbar',
	'N/A'           => 'nicht verfgbar',
	'Not Available' => 'nicht verfgbar',
	'unknown'       => 'unbekannt',
	'NONE'          => 'keine',
	'day'           => 'Tag',
	'night'         => 'Nacht',

	# first all about moon phases
	'new'             => 'Neumond',
	'first quarter'   => 'Viertelmond',
	'full'            => 'Vollmond',
	'last quarter'    => 'Dreiviertelmond',
	'waning crescent' => 'abnehmend',
	'waning gibbous'  => 'abnehmend',
	'waxing crescent' => 'zunehmend',
	'waxing gibbous'  => 'zunehmend',

	# about UV Index...
	'extreme'   => 'extrem',
	'very high' => 'sehr hoch',
	'high'      => 'hoch',
	'moderate'  => 'moderat',
	'low'       => 'niedrig',

	# tendencies used for barometric pressure
	'rising'  => 'steigend',
	'falling' => 'fallend',
	'steady'  => 'stabil',

	# all about weather conditions
	'blowing dust'                 => 'Sandsturm',
	'blowing dust and windy'       => 'Sandsturm und windig',
	'blowing snow'                 => 'Schneesturm',
	'blowing snow and windy'       => 'Schneestreiben und windig',
	'clear'                        => 'klar',
	'clear and windy'              => 'klar und windig',
	'cloudy'                       => 'bewlkt',
	'cloudy and windy'             => 'bewlkt und windig',
	'drifting snow'                => 'Schneetreiben',
	'drizzle'                      => 'Nieselregen',
	'fair'                         => 'heiter',
	'fair and windy'               => 'heiter und windig',
	'fog'                          => 'Nebel',
	'fog and windy'                => 'Nebel und windig',
	'haze'                         => 'trb',
	'haze and windy'               => 'trb und windig',
	'heavy drizzle'                => 'schwerer Sprhregen',
	'heavy rain'                   => 'schwerer Regen',
	'heavy rain and windy'         => 'schwerer Regen und windig',
	'heavy rain shower'            => 'schwere Regenschauer',
	'heavy rain shower and windy'  => 'schwere Regenschauer und windig',
	'heavy snow'                   => 'schwerer Schneefall',
	'heavy snow and windy'         => 'schwerer Schneefall und windig',
	'heavy snow shower'            => 'schwere Schneeschauer',
	'heavy t-storm'                => 'schweres Gewitter',
	'heavy t-storm and windy'      => 'schweres Gewitter und windig',
	'light drizzle'                => 'leichter Nieselregen',
	'light drizzle and windy'      => 'leichter Nieselregen und windig',
	'light freezing drizzle'       => 'leichter Eisregen',
	'light freezing drizzle and fog' => 'leichter Eisregen und Nebel',
	'light freezing rain'          => 'leichter Eisregen',
	'light rain'                   => 'leichter Regen',
	'light rain shower'            => 'leichte Regenschauer',
	'light rain shower and windy'  => 'leichte Regenschauer und windig',
	'light rain and fog'           => 'leichter Regen und Nebel',
	'light rain and freezing rain' => 'leichter Regen und Eisregen',
	'light rain with thunder'      => 'leichter Regen und Donner',
	'light rain and windy'         => 'leichter Regen und windig',
	'light snow'                   => 'leichter Schneefall',
	'light snow grains'            => 'leichte Schneegraupel',
	'light snow shower'            => 'leichte Schneeschauer',
	'light snow shower and windy'  => 'leichte Schneeschauer und windig',
	'light snow and sleet'         => 'leichter Schneefall und Schneeregen',
	'light snow and windy'         => 'leichter Schneefall und windig',
	'mist'                         => 'Sprhregen',
	'mostly cloudy'                => 'berwiegend bewlkt',
	'mostly cloudy and windy'      => 'berwiegend bewlkt und windig',
	'partial fog'                  => 'rtlich Nebel',
	'partly cloudy'                => 'teilweise bewlkt',
	'partly cloudy and windy'      => 'teilweise bewlkt und windig',
	'patches of fog'               => 'Nebelfelder',
	'rain'                         => 'Regen',
	'rain and sleet'               => 'Regen und Schneeregen',
	'rain and snow'                => 'Schneeregen',
	'rain shower'                  => 'Regenschauern',
	'rain shower and windy'        => 'Regenschauern und windig',
	'rain and fog'                 => 'Regen und Nebel',
	'rain and freezing rain'       => 'Regen und Eisregen',
	'rain and windy'               => 'Regen und windig',
	'sand'                         => 'Sand',
	'sand and windy'               => 'Sand und windig',
	'shallow fog'                  => 'Bodennebel',
	'showers in the vicinity'      => 'rtliche Schauern',
	'sleet'                        => 'Graupel',
	'smoke'                        => 'Dunst',
	'snow'                         => 'Schnee',
	'snow and fog'                 => 'Schneefall und nebelig',
	'snow and freezing rain'       => 'Schnee und Eisregen',
	'snow grains'                  => 'Schneegraupel',
	'snow showers'                 => 'Schneeschauern',
	'snow and windy and fog'       => 'Schneefall, windig und nebelig',
	'squalls'                      => 'Sturmben',
	'squalls and windy'            => 'Wind und Sturmben',
	'sunny'                        => 'sonnig',
	'sunny and windy'              => 'sonnig und windig',
	't-storm'                      => 'Gewitter',
	't-storm and windy'            => 'Gewitter und windig',
	'thunder'                      => 'Gewitter',
	'thunder and wintry mix'       => 'Gewitter und wechselnde Winde',
	'thunder in the vicinity'      => 'rtliche Gewitter',
	'unknown precip'               => 'unbekannt',
	'widespread dust'              => 'verbreitet staubig',
	'widespread dust and windy'    => 'verbreitet staubig und windig',
	'wintry mix'                   => 'wechselnde Winde',

	# wind directions long
	'East'            => 'Osten',
	'East Northeast'  => 'Ost Nordost',
	'East Southeast'  => 'Ost Sdost',
	'North'           => 'Norden',
	'Northeast'       => 'Nordosten',
	'North Northeast' => 'Nord Nordost',
	'North Northwest' => 'Nord Nordwest',
	'Northwest'       => 'Nordwesten',
	'South'           => 'Sden',
	'Souteast'        => 'Sdosten',
	'South Southeast' => 'Sd Sdost',
	'South Southwest' => 'Sd Sdwest',
	'Southwest'       => 'Sdwesten',
	'variable'        => 'wechselnd',
	'West'            => 'Westen',
	'West Northwest'  => 'West Nordwest',
	'West Southwest'  => 'West Sdwest',

	# wind directions short
	'E'   => 'O',
	'ENE' => 'ONO',
	'ESE' => 'OSO',
	'N'   => 'N',
	'NE'  => 'NO',
	'NNE' => 'NNO',
	'NNW' => 'NNW',
	'NW'  => 'NW',
	'S'   => 'S',
	'SE'  => 'SO',
	'SSE' => 'SSO',
	'SSW' => 'SSW',
	'SW'  => 'SW',
	'VAR' => 'wechselnd',
	'W'   => 'W',
	'WNW' => 'WNW',
	'WSW' => 'WSW',
);

1;
